@@ -1,8 +1,9 @@
 from abc import abstractmethod
 from typing import Any, Dict, List, Optional
 
-from pydantic import BaseModel
+from pydantic import BaseModel, PrivateAttr
 
+from obsei.misc import gpu_util
 from obsei.workflow.base_store import BaseStore
 
 
@@ -23,7 +24,7 @@ class AnalyzerResponse(BaseModel):
             "processed_text": self.processed_text,
             "segmented_data": self.segmented_data,
             "meta": self.meta,
-            "source_name": self.source_name
+            "source_name": self.source_name,
         }
 
 
@@ -35,15 +36,27 @@ class BaseAnalyzerConfig(BaseModel):
 
 
 class BaseAnalyzer(BaseModel):
+    _device_id: int = PrivateAttr()
     TYPE: str = "Base"
     store: Optional[BaseStore] = None
+    device: str = "auto"
+
+    """
+        auto: choose gpu if present else use cpu
+        cpu: use cpu
+        cuda:{id} - cuda device id
+    """
+
+    def __init__(self, **data: Any):
+        super().__init__(**data)
+        self._device_id = gpu_util.get_device_id(self.device)
 
     @abstractmethod
     def analyze_input(
-            self,
-            source_response_list: List[AnalyzerRequest],
-            analyzer_config: BaseAnalyzerConfig,
-            **kwargs
+        self,
+        source_response_list: List[AnalyzerRequest],
+        analyzer_config: BaseAnalyzerConfig,
+        **kwargs
     ) -> List[AnalyzerResponse]:
         pass
 
