@@ -1,6 +1,11 @@
 from typing import Any, List, Optional
 
-from obsei.analyzer.base_analyzer import AnalyzerRequest, AnalyzerResponse, BaseAnalyzer, BaseAnalyzerConfig
+from obsei.analyzer.base_analyzer import (
+    AnalyzerRequest,
+    AnalyzerResponse,
+    BaseAnalyzer,
+    BaseAnalyzerConfig,
+)
 
 
 class DummyAnalyzerConfig(BaseAnalyzerConfig):
@@ -13,7 +18,8 @@ class DummyAnalyzerConfig(BaseAnalyzerConfig):
 
 class DummyAnalyzer(BaseAnalyzer):
     def analyze_input(
-        self, source_response_list: List[AnalyzerRequest],
+        self,
+        source_response_list: List[AnalyzerRequest],
         analyzer_config: DummyAnalyzerConfig,
         **kwargs
     ) -> List[AnalyzerResponse]:
@@ -24,7 +30,7 @@ class DummyAnalyzer(BaseAnalyzer):
                     processed_text=source_response.processed_text,
                     meta=source_response.meta,
                     source_name=source_response.source_name,
-                    segmented_data={"data": analyzer_config.dummy_data}
+                    segmented_data={"data": analyzer_config.dummy_data},
                 )
             )
 
