@@ -1,15 +1,14 @@
+import json
 from copy import deepcopy
 from typing import Any, Dict, List
+from urllib.request import Request, urlopen
 
-import requests
-
+from obsei.misc.utils import datetime_handler
 from obsei.sink.base_sink import BaseSink, BaseSinkConfig, Convertor
 from obsei.analyzer.base_analyzer import AnalyzerResponse
 
 
-DEFAULT_HEADERS = {
-    "Content-type": "application/json"
-}
+DEFAULT_HEADERS = {"Content-type": "application/json"}
 
 
 class HttpSinkConfig(BaseSinkConfig):
@@ -38,17 +37,21 @@ class HttpSink(BaseSink):
         payloads = []
         responses = []
         for analyzer_response in analyzer_responses:
-            payloads.append(self.convertor.convert(
-                analyzer_response=analyzer_response,
-                base_payload=dict() if config.base_payload is None else deepcopy(config.base_payload)
-            ))
+            payloads.append(
+                self.convertor.convert(
+                    analyzer_response=analyzer_response,
+                    base_payload=dict()
+                    if config.base_payload is None
+                    else deepcopy(config.base_payload),
+                )
+            )
 
         for payload in payloads:
-            response = requests.post(
-                url=config.url,
-                json=payload,
-                headers=headers,
-            )
+            json_data = json.dumps(
+                payload, default=datetime_handler, ensure_ascii=False
+            ).encode("utf8")
+            req = Request(config.url, data=json_data, headers=headers)
+            response = urlopen(req)
             responses.append(response)
 
         return responses
